@@ -16,7 +16,7 @@ import threading
 import time
 
 from q4nwinlib.interactive.winpwn import process, remote
-from q4nwinlib.misc import p32, p16, p8, p64, u8, u16, u32, u64, pause, PIE, NOPIE, sleep, Latin1_encode, Latin1_decode, color, hexdump, flat, fit
+from q4nwinlib.misc import p32, p16, p8, p64, u8, u16, u32, u64, pause, PIE, NOPIE, sleep, Latin1_encode, Latin1_decode, color, hexdump, flat, fit, encode_hex, decode_hex
 from q4nwinlib.misc.log import Log
 from q4nwinlib.context import context
 from q4nwinlib.dbg import windbg, windbgx
